@@ -3,7 +3,7 @@ from typing import Union, Iterable
 import logging
 import aiohttp
 
-from asn1crypto import ocsp, x509
+from asn1crypto import ocsp, x509, cms
 
 from ... import errors
 from ..api import OCSPFetcher
@@ -11,6 +11,7 @@ from .util import AIOHttpMixin, LazySession
 from ..common_utils import (
     process_ocsp_response_data, format_ocsp_request, ocsp_job_get_earliest
 )
+from ...util import issuer_serial, get_ocsp_urls
 
 logger = logging.getLogger(__name__)
 
@@ -29,30 +30,44 @@ class AIOHttpOCSPFetcher(OCSPFetcher, AIOHttpMixin):
         self.certid_hash_algo = certid_hash_algo
         self.request_nonces = request_nonces
 
-    async def fetch(self, cert: x509.Certificate, issuer: x509.Certificate):
-        tag = (cert.issuer_serial, issuer.issuer_serial)
-        logger.info(
-            f"About to queue OCSP fetch for {cert.subject.human_friendly}..."
-        )
+    async def fetch(self,
+                    cert: Union[x509.Certificate, cms.AttributeCertificateV2],
+                    issuer: x509.Certificate) -> ocsp.OCSPResponse:
+
+        tag = (issuer_serial(cert), issuer.issuer_serial)
+        if isinstance(cert, x509.Certificate):
+            target = cert.subject.human_friendly
+        else:
+            # TODO log audit ID
+            target = "attribute certificate"
+        logger.info(f"About to queue OCSP fetch for {target}...")
 
         async def task():
             return await self._fetch(cert, issuer)
 
         return await self._post_fetch_task(tag, task)
 
-    async def _fetch(self, cert: x509.Certificate, issuer: x509.Certificate):
+    async def _fetch(self,
+                     cert: Union[x509.Certificate, cms.AttributeCertificateV2],
+                     issuer: x509.Certificate):
         ocsp_request = format_ocsp_request(
             cert, issuer, certid_hash_algo=self.certid_hash_algo,
             request_nonces=self.request_nonces
         )
         # Try the OCSP responders in arbitrary order, and process the responses
         # as they come in
-        ocsp_urls = cert.ocsp_urls
+        ocsp_urls = get_ocsp_urls(cert)
         if not ocsp_urls:
             raise errors.OCSPFetchError("No URLs to fetch OCSP responses from")
+
+        if isinstance(cert, x509.Certificate):
+            target = cert.subject.human_friendly
+        else:
+            # TODO log audit ID
+            target = "attribute certificate"
         logger.info(
-            f"Fetching OCSP status for {cert.subject.human_friendly} from "
-            f"url(s) {';'.join(ocsp_urls)}..."
+            f"Fetching OCSP status for {target} from url(s) "
+            f"{';'.join(ocsp_urls)}..."
         )
         session = await self.get_session()
         fetch_jobs = (
@@ -68,7 +83,7 @@ class AIOHttpOCSPFetcher(OCSPFetcher, AIOHttpMixin):
 
     def fetched_responses_for_cert(self, cert: x509.Certificate) \
             -> Iterable[ocsp.OCSPResponse]:
-        target_is = cert.issuer_serial
+        target_is = issuer_serial(cert)
         return {
             resp for (subj_is, _), resp in self._iter_results()
             if subj_is == target_is
