@@ -2,14 +2,13 @@
 
 import abc
 from collections import defaultdict
-from typing import List
+from typing import List, Optional, Iterable
 import asyncio
 
-from asn1crypto import pem, x509
+from asn1crypto import x509
 from oscrypto import trust_list
 
 from ._errors import pretty_message
-from ._types import byte_cls, type_name
 from .fetchers import CertificateFetcher
 from .errors import PathBuildingError, DuplicateCertificateError
 from .path import ValidationPath
@@ -173,8 +172,11 @@ class CertificateRegistry(SimpleCertificateStore):
     # Each value is a bool - if the certificate is a CA cert.
     _ca_lookup = None
 
-    def __init__(self, trust_roots=None, extra_trust_roots=None,
-                 other_certs=None, *, cert_fetcher: CertificateFetcher = None):
+    def __init__(self,
+                 trust_roots: Optional[Iterable[x509.Certificate]] = None,
+                 extra_trust_roots: Optional[Iterable[x509.Certificate]] = None,
+                 other_certs: Optional[Iterable[x509.Certificate]] = None,
+                 *, cert_fetcher: CertificateFetcher = None):
         """
         :param trust_roots:
             If the operating system's trust list should not be used, instead
@@ -196,32 +198,6 @@ class CertificateRegistry(SimpleCertificateStore):
             validated. In SSL, these would be intermediate chain certs.
         """
 
-        if trust_roots is not None and not isinstance(trust_roots, list):
-            raise TypeError(pretty_message(
-                '''
-                trust_roots must be a list of byte strings or
-                asn1crypto.x509.Certificate objects, not %s
-                ''',
-                type_name(trust_roots)
-            ))
-
-        if extra_trust_roots is not None and not isinstance(extra_trust_roots, list):
-            raise TypeError(pretty_message(
-                '''
-                extra_trust_roots must be a list of byte strings or
-                asn1crypto.x509.Certificate objects, not %s
-                ''',
-                type_name(extra_trust_roots)
-            ))
-
-        if other_certs is not None and not isinstance(other_certs, list):
-            raise TypeError(pretty_message(
-                '''
-                other_certs must be a list of byte strings or
-                asn1crypto.x509.Certificate objects, not %s
-                ''',
-                type_name(other_certs)
-            ))
         super().__init__()
 
         self._ca_lookup = set()
@@ -229,15 +205,15 @@ class CertificateRegistry(SimpleCertificateStore):
         if other_certs is None:
             other_certs = []
         else:
-            other_certs = self._validate_unarmor(other_certs, 'other_certs')
+            other_certs = list(other_certs)
 
         if trust_roots is None:
             trust_roots = [e[0] for e in trust_list.get_list()]
         else:
-            trust_roots = self._validate_unarmor(trust_roots, 'trust_roots')
+            trust_roots = list(trust_roots)
 
         if extra_trust_roots is not None:
-            trust_roots.extend(self._validate_unarmor(extra_trust_roots, 'extra_trust_roots'))
+            trust_roots.extend(extra_trust_roots)
 
         for trust_root in trust_roots:
             self.register(trust_root)
@@ -248,40 +224,6 @@ class CertificateRegistry(SimpleCertificateStore):
 
         self.fetcher = cert_fetcher
 
-    def _validate_unarmor(self, certs, var_name):
-        """
-        Takes a list of byte strings or asn1crypto.x509.Certificates objects,
-        validates and loads them while unarmoring any PEM-encoded contents
-
-        :param certs:
-            A list of byte strings or asn1crypto.x509.Certificate objects
-
-        :param var_name:
-            A unicode variable name to use in any TypeError exceptions
-
-        :return:
-            A list of asn1crypto.x509.Certificate objects
-        """
-
-        output = []
-        for cert in certs:
-            if isinstance(cert, x509.Certificate):
-                output.append(cert)
-            else:
-                if not isinstance(cert, byte_cls):
-                    raise TypeError(pretty_message(
-                        '''
-                        %s must contain only byte strings or
-                        asn1crypto.x509.Certificate objects, not %s
-                        ''',
-                        var_name,
-                        type_name(cert)
-                    ))
-                if pem.detect(cert):
-                    _, _, cert = pem.unarmor(cert)
-                output.append(x509.Certificate.load(cert))
-        return output
-
     def is_ca(self, cert):
         """
         Checks if a certificate is in the list of CA certs in this registry
@@ -301,30 +243,17 @@ class CertificateRegistry(SimpleCertificateStore):
         check via OCSP or CRL, or some other method
 
         :param cert:
-            An asn1crypto.x509.Certificate object or a byte string of a DER or
-            PEM-encoded certificate
+            An asn1crypto.x509.Certificate object
 
         :return:
             A boolean indicating if the certificate was added - will return
             False if the certificate was already present
         """
 
-        if not isinstance(cert, x509.Certificate):
-            if not isinstance(cert, byte_cls):
-                raise TypeError(pretty_message(
-                    '''
-                    cert must be a byte string or an instance of
-                    asn1crypto.x509.Certificate, not %s
-                    ''',
-                    type_name(cert)
-                ))
-            if pem.detect(cert):
-                _, _, cert = pem.unarmor(cert)
-            cert = x509.Certificate.load(cert)
-
         return self.register(cert)
 
-    def retrieve_by_name(self, name, first_certificate=None):
+    def retrieve_by_name(self, name: x509.Name,
+                         first_certificate: Optional[x509.Certificate] = None):
         """
         Retrieves a list certs via their subject name
 
@@ -339,23 +268,6 @@ class CertificateRegistry(SimpleCertificateStore):
             A list of asn1crypto.x509.Certificate objects
         """
 
-        if not isinstance(name, x509.Name):
-            raise TypeError(pretty_message(
-                '''
-                name must be an instance of asn1crypto.x509.Name, not %s
-                ''',
-                type_name(name)
-            ))
-
-        if first_certificate and not isinstance(first_certificate, x509.Certificate):
-            raise TypeError(pretty_message(
-                '''
-                first_certificate must be an instance of
-                asn1crypto.x509.Certificate, not %s
-                ''',
-                type_name(first_certificate)
-            ))
-
         output = []
         first = None
         for cert in super().retrieve_by_name(name):
@@ -388,7 +300,8 @@ class CertificateRegistry(SimpleCertificateStore):
         """
         return asyncio.run(self.async_build_paths(end_entity_cert))
 
-    async def async_build_paths(self, end_entity_cert):
+    async def async_build_paths(
+            self, end_entity_cert: x509.Certificate):
         """
         Builds a list of ValidationPath objects from a certificate in the
         operating system trust store to the end-entity certificate
@@ -403,21 +316,6 @@ class CertificateRegistry(SimpleCertificateStore):
             of the CA certs.
         """
 
-        if not isinstance(end_entity_cert, byte_cls) and \
-                not isinstance(end_entity_cert, x509.Certificate):
-            raise TypeError(pretty_message(
-                '''
-                end_entity_cert must be a byte string or an instance of
-                asn1crypto.x509.Certificate, not %s
-                ''',
-                type_name(end_entity_cert)
-            ))
-
-        if isinstance(end_entity_cert, byte_cls):
-            if pem.detect(end_entity_cert):
-                _, _, end_entity_cert = pem.unarmor(end_entity_cert)
-            end_entity_cert = x509.Certificate.load(end_entity_cert)
-
         path = ValidationPath(end_entity_cert)
         paths = []
         failed_paths = []
